![PyPI - Python Version](https://img.shields.io/pypi/pyversions/europlexo)
[![PyPI](https://img.shields.io/pypi/v/europlexo?color=red)](https://pypi.org/project/europlexo/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![GitHub](https://img.shields.io/github/license/mortafix/europlexo)

# Setup
You can find the package, [here](https://pypi.org/project/europlexo/).
```bash
pip3 install europlexo
europlexo manage
```

# Usage
```bash
europlexo manage  # manage your tv series and configure other parameters
europlexo run	# download every available episodes
```
